@@ -1,10 +1,13 @@
 class JaraError(Exception):
-    def __init__(self, message):
+    def __init__(self, message: str):
         self.message = message
 
     def __str__(self):
         return self.message
 
+    def __unicode__(self):  # pragma: no cover
+        return self.message
+
 
 class EnvironmentVariableNotFound(JaraError):
     """Raise this exception when an environment variable is not defined, but should be."""
