@@ -1,4 +1,5 @@
 from datetime import datetime, date
+from typing import Any
 
 import pytz
 
@@ -10,7 +11,7 @@ def date_2_datetime(value: date, naive: bool = False) -> datetime:
     return result.replace(tzinfo=pytz.UTC)
 
 
-def str_2_datetime(value: str, fmt: str = '%Y-%m-%d', naive: bool = False, invalid=datetime.min) -> datetime:
+def str_2_datetime(value: str, fmt: str = '%Y-%m-%d', naive: bool = False, invalid: Any = datetime.min) -> datetime:
     try:
         result = datetime.strptime(value, fmt)
     except ValueError:
